<?php

// If this file is called directly, abort.
if (!defined('WPINC')) {
    wp_die();
}

class SDOP_Main
{

    /**
     * Instance of this class.
     *
     * @since    1.0.0
     *
     * @var      object
     */
    protected static $instance = null;

    /**
     * Constructor
     *
     * @since     1.0.0
     */

    public function __construct()
    {
        // Load plugin text domain
        add_action('init', [$this, 'load_plugin_text_domain']);
        // Activate plugin when new blog is added
        add_action('wpmu_new_blog', [$this, 'activate_new_site']);

        add_action('widgets_init', [$this, 'sdop_load_widget']);
        if (SDOP_Main::check_newsfeed()) {
            add_action('wp_head', [$this, 'sdop_add_header_code']);
            add_action('wp_footer', [$this, 'sdop_add_footer_code']);
            add_filter('the_content', [$this, 'sdop_box_below_the_article'], 10); // priority 10 holds up the recommended box at the very end of the article
        }

        //Add header comment
        add_action('wp_head', [$this, 'identification_comment']);

    }

    /**
     * Return an instance of this class.
     *
     * @return    object    A single instance of this class.
     * @since     1.0.0
     *
     */
    public static function get_instance()
    {
        // If the single instance hasn't been set, set it now.
        if (null == self::$instance) {
            self::$instance = new self;
        }
        return self::$instance;
    }

    /**
     * Load the plugin text domain for translation.
     */
    public function load_plugin_text_domain()
    {
        $domain = SEZNAM_SDOP_SLUG;
        $locale = apply_filters('plugin_locale', get_locale(), $domain);

        load_textdomain($domain, trailingslashit(WP_LANG_DIR) . $domain . '/' . $domain . '-' . $locale . '.mo');
        load_plugin_textdomain($domain, FALSE, basename(dirname(__DIR__)) . '/languages/');

    }

    /**
     * Fired when a new site is activated with a WPMU environment.
     *
     * @param int $blog_id ID of the new blog.
     * @since    1.0.0
     *
     */
    public function activate_new_site($blog_id)
    {
        if (1 !== did_action('wpmu_new_blog')) {
            return;
        }

        switch_to_blog($blog_id);
        self::single_activate();
        restore_current_blog();
    }

    /**
     * Fired when the plugin is activated.
     *
     * @param boolean $network_wide True if WPMU superadmin uses
     * "Network Activate" action, false if
     *  WPMU is disabled or plugin is
     *  activated on an individual blog.
     * @since    1.0.0
     *
     */
    public static function activate($network_wide)
    {

        if (function_exists('is_multisite') && is_multisite()) {

            if ($network_wide) {

                // Get all blog ids
                $blog_ids = self::get_blog_ids();

                foreach ($blog_ids as $blog_id) {

                    switch_to_blog($blog_id);
                    self::single_activate();
                }

                restore_current_blog();

            } else {
                self::single_activate();
            }

        } else {
            self::single_activate();
        }

    }

    /**
     * Fired when the plugin is deactivated.
     *
     * @param boolean $network_wide True if WPMU superadmin uses
     * "Network Deactivate" action, false if
     *  WPMU is disabled or plugin is
     *  deactivated on an individual blog.
     * @since    1.0.0
     *
     */
    public static function deactivate($network_wide)
    {
        if (function_exists('is_multisite') && is_multisite()) {

            if ($network_wide) {

                // Get all blog ids
                $blog_ids = self::get_blog_ids();

                foreach ($blog_ids as $blog_id) {

                    switch_to_blog($blog_id);
                    self::single_deactivate();

                }

                restore_current_blog();

            } else {
                self::single_deactivate();
            }

        } else {
            self::single_deactivate();
        }
    }

    /**
     *
     */
    public function sdop_load_widget()
    {
        register_widget('SDOP_RegisterWidget');
        register_widget('SDOP_RegisterWidget_2');
    }

    /**
     *
     */
    public function sdop_add_header_code()
    {
        $web_id = get_option('sdop-web-id');
        if ($web_id) {
            echo '<script src="https://d.seznam.cz/recass/js/sznrecommend-measure.min.js" data-webid="' . $web_id . '"></script>';
            echo '<script src="https://d.seznam.cz/recass/js/sznrecommend.min.js"></script>';
        }

    }

    /**
     *
     */
    public function sdop_add_footer_code()
    {
        $web_id = get_option('sdop-web-id');
        if ($web_id) {
            echo ' <script>document.addEventListener("DOMContentLoaded", function(event) {sznRecass.getRecommendationsByTags()});</script>';
        }

    }

    /**
     * @return bool
     */
    public static function check_newsfeed()
    {

        $news_feed_checkbox = get_option('sdop-newsfeed', 'false');
        if (!$news_feed_checkbox || empty($news_feed_checkbox)) {
            return true; //Newsfeed is not required, so you can return true value all the time
        }

        if (isset($_GET['utm_source']) && isset($_GET['utm_medium']) && ($_GET['utm_source'] == 'www.seznam.cz' && $_GET['utm_medium'] == 'sekce-z-internetu')) {
            return true;
        }

        if (isset($_COOKIE[SEZNAM_SDOP_NWSFD_COOKIE])) {
            return true;
        }
        return false;
    }

    /**
     * @param $content
     * @return mixed|string
     */
    public function sdop_box_below_the_article($content)
    {

        global $post;
        if ($post && is_single() && get_post_type($post->ID) === 'post') {
            $html = '<div id="sdop-below-article-box">';
            $shortcodes = false;
            $box_ids_array = range(1, 3);
            foreach ($box_ids_array as $box_id) {
                $box_ids_array[$box_id] = get_option('sdop-box-id-' . $box_id, 0);
                if ($box_ids_array[$box_id] && is_numeric($box_ids_array[$box_id])) {
                    if (get_option('sdop-box-id-manually-' . $box_id) != '1') {
                        $shortcodes .= do_shortcode('[seznam-doporucuje id="' . $box_ids_array[$box_id] . '"]');
                    }
                }
            }
            $html .= $shortcodes . '</div>';

            if ($shortcodes) {
                return $content . $html;
            }
        }


        return $content;

    }

    /**
     * @return void
     */
    public function identification_comment(){

        $json = [
            'version' => SEZNAM_SDOP_VERSION
        ];

        $html = '<!-- seznam-doporucuje '.json_encode($json).' -->' . PHP_EOL;

        echo $html;

    }

}